;;;
;;; $Id: gnushook.el,v 1.1 1994/10/25 06:42:57 morioka Exp morioka $
;;;

(provide 'gnushook)

(require 'gnus)

(cond ((string-match "^GNUS 3" gnus-version)
       (if (and (null gnus-Startup-hook)
		(boundp 'gnus-startup-hook))
	   (setq gnus-Startup-hook gnus-startup-hook)
	 )
       (if (and (null gnus-Select-group-hook)
		(boundp 'gnus-select-group-hook))
	   (setq gnus-Select-group-hook gnus-select-group-hook)
	 )
       (if (and (null gnus-Subject-mode-hook)
		(boundp 'gnus-summary-mode-hook))
	   (setq gnus-Subject-mode-hook gnus-summary-mode-hook)
	 )
       (if (and (null gnus-Article-mode-hook)
		(boundp 'gnus-article-mode-hook))
	   (setq gnus-Article-mode-hook gnus-article-mode-hook)
	 )
       (if (and (null gnus-Article-prepare-hook)
		(boundp 'gnus-article-prepare-hook))
	   (setq gnus-Article-prepare-hook gnus-article-prepare-hook)
	 )
       )
      ((string-match "^GNUS 4" gnus-version)
       (if (and (null gnus-startup-hook)
		(boundp 'gnus-Startup-hook))
	   (setq gnus-startup-hook gnus-Startup-hook)
	 )
       (if (and (null gnus-select-group-hook)
		(boundp 'gnus-Select-group-hook))
	   (setq gnus-select-group-hook gnus-Select-group-hook)
	 )
       (if (and (null gnus-summary-mode-hook)
		(boundp 'gnus-Subject-mode-hook))
	   (setq gnus-summary-mode-hook gnus-Subject-mode-hook)
	 )
       (if (and (null gnus-article-mode-hook)
		(boundp 'gnus-Article-mode-hook))
	   (setq gnus-article-mode-hook gnus-Article-mode-hook)
	 )
       (if (and (null gnus-article-prepare-hook)
		(boundp 'gnus-Article-prepare-hook))
	   (setq gnus-article-prepare-hook gnus-Article-prepare-hook)
	 )
       ))
